@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -148,6 +151,42 @@ class ManagedIdentitiesServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ManagedIdentitiesServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ManagedIdentitiesServiceTransport:
         """Returns the transport used by the client instance.
@@ -224,6 +263,36 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a Microsoft AD domain.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_create_microsoft_ad_domain():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                domain = managedidentities_v1.Domain()
+                domain.name = "name_value"
+                domain.reserved_ip_range = "reserved_ip_range_value"
+                domain.locations = ['locations_value_1', 'locations_value_2']
+
+                request = managedidentities_v1.CreateMicrosoftAdDomainRequest(
+                    parent="parent_value",
+                    domain_name="domain_name_value",
+                    domain=domain,
+                )
+
+                # Make the request
+                operation = client.create_microsoft_ad_domain(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.CreateMicrosoftAdDomainRequest, dict]):
                 The request object. Request message for
@@ -277,7 +346,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, domain_name, domain])
         if request is not None and has_flattened_params:
@@ -338,6 +407,25 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> managed_identities_service.ResetAdminPasswordResponse:
         r"""Resets a domain's administrator password.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_reset_admin_password():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                request = managedidentities_v1.ResetAdminPasswordRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.reset_admin_password(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.ResetAdminPasswordRequest, dict]):
                 The request object. Request message for
@@ -362,7 +450,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -409,6 +497,26 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> pagers.ListDomainsAsyncPager:
         r"""Lists domains in a project.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_list_domains():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                request = managedidentities_v1.ListDomainsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_domains(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.ListDomainsRequest, dict]):
                 The request object. Request message for
@@ -436,7 +544,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -489,6 +597,25 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> resource.Domain:
         r"""Gets information about a domain.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_get_domain():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                request = managedidentities_v1.GetDomainRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_domain(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.GetDomainRequest, dict]):
                 The request object. Request message for
@@ -513,7 +640,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -561,6 +688,34 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the metadata and configuration of a domain.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_update_domain():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                domain = managedidentities_v1.Domain()
+                domain.name = "name_value"
+                domain.reserved_ip_range = "reserved_ip_range_value"
+                domain.locations = ['locations_value_1', 'locations_value_2']
+
+                request = managedidentities_v1.UpdateDomainRequest(
+                    domain=domain,
+                )
+
+                # Make the request
+                operation = client.update_domain(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.UpdateDomainRequest, dict]):
                 The request object. Request message for
@@ -601,7 +756,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([domain, update_mask])
         if request is not None and has_flattened_params:
@@ -660,6 +815,29 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a domain.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_delete_domain():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                request = managedidentities_v1.DeleteDomainRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_domain(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.DeleteDomainRequest, dict]):
                 The request object. Request message for
@@ -697,7 +875,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -753,6 +931,37 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Adds an AD trust to a domain.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_attach_trust():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                trust = managedidentities_v1.Trust()
+                trust.target_domain_name = "target_domain_name_value"
+                trust.trust_type = "EXTERNAL"
+                trust.trust_direction = "BIDIRECTIONAL"
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.trust_handshake_secret = "trust_handshake_secret_value"
+
+                request = managedidentities_v1.AttachTrustRequest(
+                    name="name_value",
+                    trust=trust,
+                )
+
+                # Make the request
+                operation = client.attach_trust(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.AttachTrustRequest, dict]):
                 The request object. Request message for
@@ -786,7 +995,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, trust])
         if request is not None and has_flattened_params:
@@ -845,6 +1054,31 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the DNS conditional forwarder.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_reconfigure_trust():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                request = managedidentities_v1.ReconfigureTrustRequest(
+                    name="name_value",
+                    target_domain_name="target_domain_name_value",
+                    target_dns_ip_addresses=['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2'],
+                )
+
+                # Make the request
+                operation = client.reconfigure_trust(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.ReconfigureTrustRequest, dict]):
                 The request object. Request message for
@@ -889,7 +1123,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, target_domain_name, target_dns_ip_addresses])
         if request is not None and has_flattened_params:
@@ -949,6 +1183,37 @@ class ManagedIdentitiesServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Removes an AD trust.
 
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_detach_trust():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                trust = managedidentities_v1.Trust()
+                trust.target_domain_name = "target_domain_name_value"
+                trust.trust_type = "EXTERNAL"
+                trust.trust_direction = "BIDIRECTIONAL"
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.trust_handshake_secret = "trust_handshake_secret_value"
+
+                request = managedidentities_v1.DetachTrustRequest(
+                    name="name_value",
+                    trust=trust,
+                )
+
+                # Make the request
+                operation = client.detach_trust(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.DetachTrustRequest, dict]):
                 The request object. Request message for
@@ -984,7 +1249,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, trust])
         if request is not None and has_flattened_params:
@@ -1044,6 +1309,38 @@ class ManagedIdentitiesServiceAsyncClient:
         reachable, and that the target domain is able to accept
         incoming trust requests.
 
+
+        .. code-block:: python
+
+            from google.cloud import managedidentities_v1
+
+            def sample_validate_trust():
+                # Create a client
+                client = managedidentities_v1.ManagedIdentitiesServiceClient()
+
+                # Initialize request argument(s)
+                trust = managedidentities_v1.Trust()
+                trust.target_domain_name = "target_domain_name_value"
+                trust.trust_type = "EXTERNAL"
+                trust.trust_direction = "BIDIRECTIONAL"
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.trust_handshake_secret = "trust_handshake_secret_value"
+
+                request = managedidentities_v1.ValidateTrustRequest(
+                    name="name_value",
+                    trust=trust,
+                )
+
+                # Make the request
+                operation = client.validate_trust(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.managedidentities_v1.types.ValidateTrustRequest, dict]):
                 The request object. Request message for
@@ -1079,7 +1376,7 @@ class ManagedIdentitiesServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, trust])
         if request is not None and has_flattened_params:
